@@ -24,6 +24,7 @@
 #ifndef _MANAGER_SERVER_GENERIC_H
 #define _MANAGER_SERVER_GENERIC_H
 
+#include <gnutls/gnutls.h>
 #include <libprelude/prelude-inttypes.h>
 
 
@@ -42,8 +43,8 @@
         unsigned int port;           \
         uint64_t ident;              \
         char *permission_string;     \
-        pthread_mutex_t mutex;       \
-        prelude_connection_permission_t permission
+        prelude_connection_permission_t permission; \
+        gnutls_alert_description alert
 
 
 typedef struct server_generic server_generic_t;
@@ -83,6 +84,8 @@ server_generic_t *server_generic_new(size_t serverlen,
 
 int server_generic_bind(server_generic_t *server, const char *addr, unsigned int port);
 
+int server_generic_bind_numeric(server_generic_t *server, struct sockaddr *sa, socklen_t len, unsigned int port);
+
 void server_generic_start(server_generic_t **server, size_t nserver);
 
 void server_generic_close(server_generic_t *server);
@@ -101,6 +104,8 @@ int server_generic_client_get_state(server_generic_client_t *client);
 
 void server_generic_client_set_state(server_generic_client_t *client, int state);
 
+void server_generic_remove_client(server_generic_t *server, server_generic_client_t *client);
+
 #endif /* _MANAGER_SERVER_GENERIC_H */
 
 
