@@ -92,7 +92,7 @@ static int handle_heartbeat_msg(prelude_msg_t *msg, idmef_message_t *idmef)
                 idmef_heartbeat_set_analyzer_time(heartbeat, analyzer_time);
         }
 
-        idmef_heartbeat_set_analyzer(heartbeat, idmef_analyzer_ref(prelude_client_get_analyzer(manager_client)), 0);
+        idmef_heartbeat_set_analyzer(heartbeat, idmef_analyzer_ref(prelude_client_get_analyzer(manager_client)), IDMEF_LIST_PREPEND);
         
         return 0;
 }
@@ -122,7 +122,7 @@ static int handle_alert_msg(prelude_msg_t *msg, idmef_message_t *idmef)
                 idmef_alert_set_analyzer_time(alert, analyzer_time);
         }       
 
-        idmef_alert_set_analyzer(alert, idmef_analyzer_ref(prelude_client_get_analyzer(manager_client)), 0);
+        idmef_alert_set_analyzer(alert, idmef_analyzer_ref(prelude_client_get_analyzer(manager_client)), IDMEF_LIST_PREPEND);
         
         return 0;
 }
@@ -183,8 +183,8 @@ int pmsg_to_idmef(idmef_message_t **idmef, prelude_msg_t *msg)
         }
         
         if ( prelude_error_get_code(ret) == PRELUDE_ERROR_EOF )
-                return 0;
-
+                return decode_plugins_run(0, NULL, *idmef);
+        
         prelude_log(PRELUDE_LOG_INFO, "%s: error reading IDMEF message: %s.\n", prelude_strsource(ret), prelude_strerror(ret));
         idmef_message_destroy(*idmef);
                 
